<?php
namespace Aheadworks\Followupemail2\Helper;

use Aheadworks\Followupemail2\Api\Data\EventInterface;
use Magento\Quote\Api\CartRepositoryInterface;
use Aheadworks\Followupemail2\Api\EventHistoryManagementInterface;
use Aheadworks\Followupemail2\Api\EventHistoryRepositoryInterface;

/**
 * Class Data
 * @package Aheadworks\Followupemail2\Helper
 */
class Data
{
    /**
     * @var CartRepositoryInterface
     */
    private $quoteRepository;
    /**
     * @var EventHistoryManagementInterface
     */
    private $eventHistoryManagement;
    /**
     * @var EventHistoryRepositoryInterface
     */
    private $eventHistoryRepository;


    /**
     * Data constructor.
     * @param CartRepositoryInterface $quoteRepository
     * @param EventHistoryManagementInterface $eventHistoryManagement
     * @param EventHistoryRepositoryInterface $eventHistoryRepository
     */
    public function __construct(
        CartRepositoryInterface $quoteRepository,
        EventHistoryManagementInterface $eventHistoryManagement,
        EventHistoryRepositoryInterface $eventHistoryRepository){
        $this->quoteRepository = $quoteRepository;
        $this->eventHistoryManagement = $eventHistoryManagement;
        $this->eventHistoryRepository = $eventHistoryRepository;
    }


    /**
     * @param $eventHistoryItem
     * @return bool
     */
    public function isRevoverableCart($eventHistoryItem){
        try{
            $cartId = $eventHistoryItem->getReferenceId();
            $quote = $this->quoteRepository->get($cartId);
            if(!$quote->getCustomerIsGuest()){
                $customerEmail = $quote->getCustomer()->getEmail();
                $customer=$quote->getCustomer();
                if($customer->getBillingAddress()){
                    $customerName = $quote->getBillingAddress()->getFirstname() . ' ' . $quote->getBillingAddress()->getLastname();
                }else{
                    return false;
                }
                $cartData = array_merge($quote->getData(), [
                    'email' => $customerEmail,
                    'customer_name' => $customerName
                ]);
                $this->eventHistoryManagement->addEvent(EventInterface::TYPE_ABANDONED_CART, $cartData);
                $this->eventHistoryRepository->delete($eventHistoryItem);
                return true;
            }else{
                //delete data
                $this->eventHistoryRepository->delete($eventHistoryItem);
                return false;
            }
        }catch (\Exception $e){
            //delete data
            $this->eventHistoryRepository->delete($eventHistoryItem);
            return false;
        }catch (\Throwable $t){
            //delete data
            $this->eventHistoryRepository->delete($eventHistoryItem);
            return false;
        }

    }


}